import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:unicons/unicons.dart';

import 'package:random/config/theme.dart';
import 'package:random/cubit/data_cubit.dart';
import 'package:random/cubit/settings_cubit.dart';
import 'package:random/ui/widgets/header_app.dart';

class DemoPage extends StatelessWidget {
  const DemoPage({super.key});

  @override
  Widget build(BuildContext context) {
    return Material(
      color: Theme.of(context).colorScheme.background,
      child: ListView(
        padding: const EdgeInsets.symmetric(horizontal: 4),
        physics: const BouncingScrollPhysics(),
        children: <Widget>[
          SizedBox(height: 8),
          AppHeader(text: 'TOP'),
          SizedBox(height: 20),
          persistedCounterBlock(),
          SizedBox(height: 20),
          fakeApiCall(),
          SizedBox(height: 20),
          AppHeader(text: 'BOTTOM'),
        ],
      ),
    );
  }

  Widget persistedCounterBlock() {
    return BlocProvider<DataCubit>(
      create: (BuildContext context) => DataCubit(),
      child: BlocBuilder<DataCubit, DataState>(
        builder: (BuildContext context, DataState state) {
          void updateCounter(int delta) {
            BlocProvider.of<DataCubit>(context).getData(
              DataState(counter: (state.counter ?? 0) + delta),
            );
          }

          return Row(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              IconButton(
                icon: Icon(UniconsSolid.arrow_circle_down),
                color: appTheme.primaryColor,
                onPressed: () => updateCounter(-1),
              ),
              Padding(
                padding: EdgeInsets.all(10),
                child: Text(state.counter.toString()),
              ),
              IconButton(
                icon: Icon(UniconsSolid.arrow_circle_up),
                color: appTheme.primaryColor,
                onPressed: () => updateCounter(1),
              ),
            ],
          );
        },
      ),
    );
  }

  Widget fakeApiCall() {
    return BlocProvider<SettingsCubit>(
      create: (BuildContext context) => SettingsCubit(),
      child: BlocBuilder<SettingsCubit, SettingsState>(
        builder: (BuildContext context, SettingsState state) {
          SettingsCubit settings = BlocProvider.of<SettingsCubit>(context);

          return Column(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Text('apiUrl: ' + settings.getSetting('apiUrl')),
              Text('securityToken: ' + settings.getSetting('securityToken')),
              Text('unknown: ' + settings.getSetting('unknown', 'undefined')),
            ],
          );
        },
      ),
    );
  }
}
